import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { DragProps, Item } from '@highlight-ui/drag-and-drop';
export declare type AccordionSection = PropsWithMetadata<{
    /**
     * The section's react `key` prop. This property should be unique in the `sections` array
     */
    key: string;
    /**
     * The component or string to show as the section's title
     */
    title: React.ReactNode;
    /**
     * The component or string to mount in the expandable contents part of the section
     */
    content: React.ReactNode;
    /**
     * The components or string provided by this property will be mounted on the right side of the section's title
     */
    actions?: React.ReactNode;
    /**
     * Should the section be noninteractive?
     */
    disabled?: boolean;
}>;
export declare type StaticAccordionProps = PropsWithMetadata<{
    /**
     * Sets the root element's class attribute
     */
    className?: string;
    /**
     * Callback fired whenever the section opens or closes.
     */
    onExpansionChange?: (section: AccordionSection, isExpanded: boolean, index: number) => void;
    /**
     * The sections which are open by default. ⚠️ In case `multiple` is set to false, only the first array element will be opened.
     */
    initiallyOpen?: AccordionSection[];
    /**
     * Should multiple sections remain open?
     */
    multiple?: boolean;
    /**
     * Will be called with each selection change when the `selectable` prop is `true`.
     */
    onSelectedSectionsChange?: (sections: AccordionSection[]) => void;
    /**
     * An array of `Section` data structure
     */
    sections: AccordionSection[];
    /**
     * Should segments be selectable using a check box?
     */
    selectable?: boolean;
    /**
     * Indicates the selected checkboxes in sections
     */
    selectedSections?: AccordionSection[];
}>;
export declare type DraggableAccordionProps<D extends Item = Item> = StaticAccordionProps & {
    /**
     * Configuration for drag-and-drop capabilities
     */
    dragProps: DragProps<AccordionSection, D>;
};
export declare type AccordionProps<D extends Item = Item> = Partial<DraggableAccordionProps<D>> & StaticAccordionProps;
